import java.util.Random;
import java.util.List;
import java.util.Collections;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.stream.Collectors;
import java.util.stream.IntStream;
import java.util.Comparator;

/**
 * {@link java.util.Arrays#sort(Object[])}の簡易的なベンチマーククラス.
 * <p>
 * 旧アルゴリズムで実行する場合は{@literal -Djava.util.Arrays.useLegacyMergeSort=true}を指定して実行する.
 * </p>
 */
class ArraysSortSimpleBenchmark {
    public static void main(String... args) {
       
        int size = 1_0000_0000;
        IntStream intStream = IntStream.range(0, size);
        List<Integer> source = new ArrayList<>(intStream.boxed().toList());
        Random r = new Random(432543534);
        Collections.shuffle(source, r);
	System.out.println("test starts");
	if ("1".equals(args[0])) {
            long startL1 = System.nanoTime();        	
            Arrays.sort(source.toArray(new Integer[size]));
            long endL1 = System.nanoTime();
            System.out.println(endL1 - startL1);
	} else if ("2".equals(args[0])) {
            List<String> l2 = source.stream().map(i -> i.toString()).collect(Collectors.toList());
            long startL2 = System.nanoTime();        	
            Arrays.sort(l2.toArray(new String[size]));
            long endL2 = System.nanoTime();
            System.out.println(endL2 - startL2);
		
	} else if ("3".equals(args[0])) {
            List<Integer> l3 = new ArrayList<>(source);
            Collections.sort(l3, Comparator.reverseOrder());
            long startL3 = System.nanoTime();        	
            Arrays.sort(l3.toArray(new Integer[size]));
            long endL3 = System.nanoTime();
            System.out.println(endL3 - startL3);

	} else if ("4".equals(args[0])) {
            List<String> l4 = source.stream().map(i -> i.toString()).sorted(Comparator.reverseOrder()).collect(Collectors.toList());
            long startL4 = System.nanoTime();        	
            Arrays.sort(l4.toArray(new String[size]));
            long endL4 = System.nanoTime();
            System.out.println(endL4 - startL4);
	} else { 
            System.out.println("No test");
        }
    }
}
